@@ -323,8 +323,7 @@ class RTMClient(object):
             try:
                 self._connection_attempts += 1
                 async with aiohttp.ClientSession(
-                    loop=self._event_loop,
-                    timeout=aiohttp.ClientTimeout(total=self.timeout),
+                    timeout=aiohttp.ClientTimeout(total=self.timeout)
                 ) as session:
                     self._session = session
                     url, data = await self._retreive_websocket_info()
